@@ -2,7 +2,7 @@ from .exceptions import BadInputException, InvalidAuthentication, InternalServer
 from .code import NimbleCodes
 from .settings import SUCCESS_CODES
 from django.http import QueryDict
-from .utils import Utils
+from log_labeler.utils import Utils
 import requests
 import json
 import os
@@ -44,7 +44,7 @@ class NimbleHelper:
 
         args = {
             "action": soap_action,
-            "data": Utils.adjust_string_length(Utils.obfuscate_body(json.dumps(params)), max_request_response_size),
+            "data": Utils.obfuscate_body(Utils.adjust_string_length(json.dumps(params), max_request_response_size)),
             "headers": Utils.obfuscate_headers(headers),
             "url": Utils.obfuscate_url(gateway_url),
             "service": service_name
@@ -60,8 +60,8 @@ class NimbleHelper:
         logger.debug({
             "status_code": results.status_code,
             "request_headers": Utils.obfuscate_headers(headers),
-            "response_content": Utils.adjust_string_length(Utils.obfuscate_body(decoded_response),
-                                                           max_request_response_size) \
+            "response_content": Utils.obfuscate_body(Utils.adjust_string_length(decoded_response,
+                                                                                max_request_response_size))
                 if results.status_code < 400 else Utils.obfuscate_response(decoded_response)
         })
         response = json.loads(decoded_response)
